# lingo - payment and billing system
# Copyright (C) 2022  Entr'ouvert
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from django.urls import path, re_path

from . import views

urlpatterns = [
    re_path(
        r'^agenda/(?P<agenda_identifier>[\w-]+)/check-types/$',
        views.agenda_check_type_list,
        name='api-agenda-check-types',
    ),
    path(
        'pricing/compute/',
        views.pricing_compute,
        name='api-pricing-compute',
    ),
    path(
        'regies/',
        views.invoicing_regies,
        name='api-invoicing-regies',
    ),
    re_path(
        r'^regie/(?P<regie_identifier>[\w-]+)/payment-types/$',
        views.invoicing_payment_types,
        name='api-invoicing-payment-types',
    ),
    re_path(
        r'^regie/(?P<regie_identifier>[\w-]+)/invoices/$',
        views.invoicing_invoices,
        name='api-invoicing-invoices',
    ),
    re_path(
        r'^regie/(?P<regie_identifier>[\w-]+)/invoices/history/$',
        views.invoicing_history_invoices,
        name='api-invoicing-history-invoices',
    ),
    re_path(
        r'^regie/(?P<regie_identifier>[\w-]+)/invoice/'
        r'(?P<invoice_identifier>[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12})/$',
        views.invoicing_invoice,
        name='api-invoicing-invoice',
    ),
    re_path(
        r'^regie/(?P<regie_identifier>[\w-]+)/invoice/'
        r'(?P<invoice_identifier>[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12})/pdf/$',
        views.invoicing_invoice_pdf,
        name='api-invoicing-invoice-pdf',
    ),
    re_path(
        r'^regie/(?P<regie_identifier>[\w-]+)/invoice/'
        r'(?P<invoice_identifier>[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12})/pay/$',
        views.invoicing_invoice_pay,
        name='api-invoicing-invoice-pay',
    ),
    re_path(
        r'^regie/(?P<regie_identifier>[\w-]+)/draft-invoices/$',
        views.invoicing_draft_invoices,
        name='api-invoicing-draft-invoices',
    ),
    re_path(
        r'^regie/(?P<regie_identifier>[\w-]+)/draft-invoice/'
        r'(?P<invoice_identifier>[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12})/lines/$',
        views.invoicing_draft_invoice_lines,
        name='api-invoicing-draft-invoice-lines',
    ),
    re_path(
        r'^regie/(?P<regie_identifier>[\w-]+)/draft-invoice/'
        r'(?P<invoice_identifier>[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12})/close/$',
        views.invoicing_draft_invoice_close,
        name='api-invoicing-draft-invoice-close',
    ),
    re_path(
        r'^regie/(?P<regie_identifier>[\w-]+)/injected-lines/$',
        views.injected_lines,
        name='api-invoicing-injected-lines',
    ),
    re_path(
        r'^regie/(?P<regie_identifier>[\w-]+)/payments/$',
        views.payments,
        name='api-invoicing-payments',
    ),
]
